@@ -1,6 +1,6 @@
 package UI::Dialog;
 ###############################################################################
-#  Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
+#  Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -18,11 +18,13 @@ package UI::Dialog;
 ###############################################################################
 use 5.006;
 use strict;
+use warnings;
+use diagnostics;
 use Carp;
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION = '1.09';
+    $VERSION = '1.01';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -37,15 +39,7 @@ sub new {
     bless($self, $class);
 
     $self->{'debug'} = $cfg->{'debug'} || 0;
-
-	#: Dynamic path discovery...
-	my $CFG_PATH = $cfg->{'PATH'};
-	if ($CFG_PATH) {
-		if (ref($CFG_PATH) eq "ARRAY") { $self->{'PATHS'} = $CFG_PATH; }
-		elsif ($CFG_PATH =~ m!:!) { $self->{'PATHS'} = [ split(/:/,$CFG_PATH) ]; }
-		elsif (-d $CFG_PATH) { $self->{'PATHS'} = [ $CFG_PATH ]; }
-	} elsif ($ENV{'PATH'}) { $self->{'PATHS'} = [ split(/:/,$ENV{'PATH'}) ]; }
-	else { $self->{'PATHS'} = ''; }
+    $self->{'PATH'} = $cfg->{'PATH'} || '';
 
     if (not $cfg->{'order'} and ($ENV{'DISPLAY'} && length($ENV{'DISPLAY'}) > 0)) {
 		#: Pick a GUI mode 'cause a DISPLAY was detected
@@ -53,8 +47,11 @@ sub new {
 			# we're running free of a terminal
 			$cfg->{'order'} = [ 'zenity', 'xdialog', 'gdialog', 'kdialog' ];
 		} else {
-			# we're running in a terminal
-            $cfg->{'order'} = [ 'zenity', 'xdialog', 'gdialog', 'kdialog', 'whiptail', 'cdialog', 'ascii' ];
+			#: we're running in a terminal, currently we do the same as a dumb term
+			#: but I'm not 100% sure that this is the right thing to do.
+			$cfg->{'order'} = [ 'zenity', 'xdialog', 'gdialog', 'kdialog' ];
+			#: this would the the alternative:
+			#$cfg->{'order'} = [ 'whiptail', 'cdialog', 'ascii' ];
 		}
     }
     # verify and repair the order
@@ -675,7 +672,7 @@ TRUE (1) if the response is OK and FALSE (0) for anything else.
 
 =over 2
 
-=head2 menu( )
+=head2 menubox( )
 
 =over 4
 
@@ -683,10 +680,10 @@ TRUE (1) if the response is OK and FALSE (0) for anything else.
 
 =over 6
 
- my $selection1 = $d->menu( text => 'Select one:',
-                            list => [ 'tag1', 'item1',
-                                      'tag2', 'item2',
-                                      'tag3', 'item3' ] );
+ my $selection1 = $d->menubox( text => 'Select one:',
+                               list => [ 'tag1', 'item1',
+                                         'tag2', 'item2',
+                                         'tag3', 'item3' ] );
 
 =back
 
@@ -896,11 +893,11 @@ module in the subject line.
 
 =head1 AUTHOR
 
-Kevin C. Krinke, E<lt>kevin@krinke.caE<gt>
+Kevin C. Krinke, E<lt>kckrinke@opendoorsoftware.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
- Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
+ Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
