@@ -1,6 +1,6 @@
 package UI::Dialog::Backend::GDialog;
 ###############################################################################
-#  Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
+#  Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,8 @@ package UI::Dialog::Backend::GDialog;
 ###############################################################################
 use 5.006;
 use strict;
+use warnings;
+use diagnostics;
 use FileHandle;
 use Carp;
 use UI::Dialog::Backend;
@@ -25,7 +27,7 @@ use UI::Dialog::Backend;
 BEGIN {
     use vars qw( $VERSION @ISA );
     @ISA = qw( UI::Dialog::Backend );
-    $VERSION = '1.09';
+    $VERSION = '1.01';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -40,17 +42,6 @@ sub new {
     bless($self, $class);
     $self->{'_state'} = {};
     $self->{'_opts'} = {};
-
-	#: Dynamic path discovery...
-	my $CFG_PATH = $cfg->{'PATH'};
-	if ($CFG_PATH) {
-		if (ref($CFG_PATH) eq "ARRAY") { $self->{'PATHS'} = $CFG_PATH; }
-		elsif ($CFG_PATH =~ m!:!) { $self->{'PATHS'} = [ split(/:/,$CFG_PATH) ]; }
-		elsif (-d $CFG_PATH) { $self->{'PATHS'} = [ $CFG_PATH ]; }
-	} elsif ($ENV{'PATH'}) { $self->{'PATHS'} = [ split(/:/,$ENV{'PATH'}) ]; }
-	else { $self->{'PATHS'} = ''; }
-
-	$self->{'_opts'}->{'literal'} = $cfg->{'literal'} || 0;
     $self->{'_opts'}->{'callbacks'} = $cfg->{'callbacks'} || undef();
     $self->{'_opts'}->{'debug'} = $cfg->{'debug'} || undef();
     $self->{'_opts'}->{'title'} = $cfg->{'title'} || undef();
@@ -122,7 +113,7 @@ sub yesno {
     my $args = $self->_pre($caller,@_);
 
     my $command = $self->_mk_cmnd(' --yesno',@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'})||' ') . '"';
     $command .= ' "' . ($args->{'height'}||'20') . '"';
     $command .= ' "' . ($args->{'width'}||'65') . '"';
 
@@ -153,7 +144,7 @@ sub inputbox {
     my $args = $self->_pre($caller,@_);
 
     my $command = $self->_mk_cmnd(' --inputbox',@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'})||' ') . '"';
     $command .= ' "' . ($args->{'height'}||'20') . '"';
     $command .= ' "' . ($args->{'width'}||'65') . '"';
     $command .= ' "' . ($args->{'init'}||'') . '"'
@@ -194,7 +185,7 @@ sub msgbox {
     $args->{'msgbox'} ||= 'msgbox';
 
     my $command = $self->_mk_cmnd(' --'.$args->{'msgbox'},@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'})||' ') . '"';
     $command .= ' "' . ($args->{'height'}||'20') . '"';
     $command .= ' "' . ($args->{'width'}||'65') . '"';
 
@@ -256,7 +247,7 @@ sub menu {
     my $args = $self->_pre($caller,@_);
 
     my $command = $self->_mk_cmnd(" --menu",@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'})||' ') . '"';
     $command .= ' "' . ($args->{'height'}||'20') . '"';
     $command .= ' "' . ($args->{'width'}||'65') . '"';
     $command .= ' "' . ($args->{'menuheight'}||$args->{'listheight'}||'5') . '"';
@@ -301,7 +292,7 @@ sub checklist {
     $self->{'checklist'} ||= 'checklist';
 
     my $command = $self->_mk_cmnd(" --".$self->{'checklist'},@_,'separate-output',1);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'})||' ') . '"';
     $command .= ' "' . ($args->{'height'}||'20') . '"';
     $command .= ' "' . ($args->{'width'}||'65') . '"';
     $command .= ' "' . ($args->{'menuheight'}||$args->{'listheight'}||'5') . '"';
@@ -349,7 +340,7 @@ sub radiolist {
     $self->{'radiolist'} ||= 'radiolist';
 
     my $command = $self->_mk_cmnd(" --".$self->{'radiolist'},@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'})||' ') . '"';
     $command .= ' "' . ($args->{'height'}||'20') . '"';
     $command .= ' "' . ($args->{'width'}||'65') . '"';
     $command .= ' "' . ($args->{'menuheight'}||$args->{'listheight'}||'5') . '"';
@@ -395,7 +386,7 @@ sub radiolist {
 #     $self->_beep($args->{'beepbefore'});
 
 #     my $command = $self->_mk_cmnd(" --gauge",@_);
-#    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'}))||' ') . '"';
+#     $command .= ' "' . ($self->_organize_text($args->{'text'})||' ') . '"';
 #     $command .= ' "' . ($args->{'height'}||'20') . '"';
 #     $command .= ' "' . ($args->{'width'}||'65') . '"';
 #     $command .= ' "' . ($args->{'percentage'}||'0') . '"';
