@@ -1,6 +1,6 @@
 package UI::Dialog::Backend::KDialog;
 ###############################################################################
-#  Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
+#  Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,8 @@ package UI::Dialog::Backend::KDialog;
 ###############################################################################
 use 5.006;
 use strict;
+use warnings;
+use diagnostics;
 use Carp;
 use Cwd qw( abs_path );
 use UI::Dialog::Backend;
@@ -25,7 +27,7 @@ use UI::Dialog::Backend;
 BEGIN {
     use vars qw( $VERSION @ISA );
     @ISA = qw( UI::Dialog::Backend );
-    $VERSION = '1.09';
+    $VERSION = '1.01';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -40,17 +42,6 @@ sub new {
     bless($self, $class);
     $self->{'_state'} = {};
     $self->{'_opts'} = {};
-
-	#: Dynamic path discovery...
-	my $CFG_PATH = $cfg->{'PATH'};
-	if ($CFG_PATH) {
-		if (ref($CFG_PATH) eq "ARRAY") { $self->{'PATHS'} = $CFG_PATH; }
-		elsif ($CFG_PATH =~ m!:!) { $self->{'PATHS'} = [ split(/:/,$CFG_PATH) ]; }
-		elsif (-d $CFG_PATH) { $self->{'PATHS'} = [ $CFG_PATH ]; }
-	} elsif ($ENV{'PATH'}) { $self->{'PATHS'} = [ split(/:/,$ENV{'PATH'}) ]; }
-	else { $self->{'PATHS'} = ''; }
-
-	$self->{'_opts'}->{'literal'} = $cfg->{'literal'} || 0;
     $self->{'_opts'}->{'callbacks'} = $cfg->{'callbacks'} || undef();
     $self->{'_opts'}->{'debug'} = $cfg->{'debug'} || undef();
     $self->{'_opts'}->{'caption'} = $cfg->{'caption'} || undef();
@@ -157,7 +148,7 @@ sub yesno {
     $args->{'yesno'} ||= "yesno";
 
     my $command = $self->_mk_cmnd(' --'.$args->{'yesno'},@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"';
 
     my $rv = $self->command_state($command);
     $self->rv($rv||'null');
@@ -210,7 +201,7 @@ sub inputbox {
     $args->{'inputbox'} ||= 'inputbox';
 
     my $command = $self->_mk_cmnd(' --'.$args->{'inputbox'},@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"';
     $command .= ' "' . ($args->{'init'}||$args->{'entry'}||'') . '"'
      unless
       (not $args->{'init'} and not $args->{'entry'})
@@ -248,7 +239,7 @@ sub msgbox {
     $args->{'msgbox'} ||= 'msgbox';
 
     my $command = $self->_mk_cmnd(' --'.$args->{'msgbox'},@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"';
 
     my $rv = $self->command_state($command);
     $self->rv($rv||'null');
@@ -310,7 +301,7 @@ sub menu {
     my $args = $self->_pre($caller,@_);
 
     my $command = $self->_mk_cmnd(" --menu",@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"';
 
     if ($args->{'list'}) {
 		$args->{'list'} = [ ' ', ' ' ] unless ref($args->{'list'}) eq "ARRAY";
@@ -352,7 +343,7 @@ sub checklist {
     $self->{'checklist'} ||= 'checklist';
 
     my $command = $self->_mk_cmnd(" --".$self->{'checklist'},@_,'separate-output',1);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"';
 
     if ($args->{'list'}) {
 		$args->{'list'} = [ ' ', [' ', 1] ] unless ref($args->{'list'}) eq "ARRAY";
@@ -397,7 +388,7 @@ sub radiolist {
     $self->{'radiolist'} ||= 'radiolist';
 
     my $command = $self->_mk_cmnd(" --".$self->{'radiolist'},@_);
-    $command .= ' "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"';
+    $command .= ' "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"';
 
     if ($args->{'list'}) {
 		$args->{'list'} = [ ' ', [' ', 1] ] unless ref($args->{'list'}) eq "ARRAY";
