@@ -1,6 +1,6 @@
 package UI::Dialog::Backend::Zenity;
 ###############################################################################
-#  Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
+#  Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,8 @@ package UI::Dialog::Backend::Zenity;
 ###############################################################################
 use 5.006;
 use strict;
+use warnings;
+use diagnostics;
 use FileHandle;
 use Cwd qw( abs_path );
 use Carp;
@@ -26,7 +28,7 @@ use UI::Dialog::Backend;
 BEGIN {
     use vars qw( $VERSION @ISA );
     @ISA = qw( UI::Dialog::Backend );
-    $VERSION = '1.09';
+    $VERSION = '1.01';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -41,17 +43,6 @@ sub new {
     bless($self, $class);
     $self->{'_state'} = {};
     $self->{'_opts'} = {};
-
-	#: Dynamic path discovery...
-	my $CFG_PATH = $cfg->{'PATH'};
-	if ($CFG_PATH) {
-		if (ref($CFG_PATH) eq "ARRAY") { $self->{'PATHS'} = $CFG_PATH; }
-		elsif ($CFG_PATH =~ m!:!) { $self->{'PATHS'} = [ split(/:/,$CFG_PATH) ]; }
-		elsif (-d $CFG_PATH) { $self->{'PATHS'} = [ $CFG_PATH ]; }
-	} elsif ($ENV{'PATH'}) { $self->{'PATHS'} = [ split(/:/,$ENV{'PATH'}) ]; }
-	else { $self->{'PATHS'} = ''; }
-
-	$self->{'_opts'}->{'literal'} = $cfg->{'literal'} || 0;
     $self->{'_opts'}->{'debug'} = $cfg->{'debug'} || undef();
     $self->{'_opts'}->{'window-icon'} = $cfg->{'window-icon'} || undef();
     $self->{'_opts'}->{'title'} = $cfg->{'title'} || undef();
@@ -74,9 +65,7 @@ sub new {
 		croak("the zenity binary could not be found at: ".$self->{'_opts'}->{'bin'});
     }
 
-    my $command = $self->{'_opts'}->{'bin'}." --version";
-    my $version = `$command 2>&1`;
-    chomp( $version );
+    chomp(my $version = $self->command_string($self->{'_opts'}->{'bin'}." --version"));
     $self->{'ZENITY_VERSION'} = $version || '1';
 
     return($self);
@@ -122,21 +111,11 @@ sub _mk_cmnd {
 
     return($cmnd);
 }
-sub _is_bad_version {
+sub _is_version {
     my $self = shift();
-    my ($d_maj, $d_min, $d_mac) = ( 1, 4, 0 );
-    my ($z_maj, $z_min, $z_mac) = ( 0, 0, 0 );
-    my $zenity_version = $self->{'ZENITY_VERSION'} || '0.0.0';
-    if ( $zenity_version =~ m!^(\d+)\.(\d+)\.(\d+)$! ) {
-        ($z_maj, $z_min, $z_mac) = ( $1, $2, $3 );
-    }
-    if ( ( $d_maj <  $z_maj                                        ) ||
-         ( $d_maj == $z_maj && $d_min <  $z_min                    ) ||
-         ( $d_maj == $z_maj && $d_min == $z_min && $d_mac < $z_mac )
-       ) {
-        return(0);
-    }
-    return(1);
+    my $desired_version = shift() || $self->{'ZENITY_VERSION'} || '1';
+    if ($desired_version <= ($self->{'ZENITY_VERSION'}||'1')) { return(1); }
+    else { return(0); }
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -160,7 +139,7 @@ sub command_string {
     my $cmnd = $_[1];
     $self->_debug("command: ".$cmnd,1);
     my $text;
-    if ($self->_is_bad_version()) {
+    if ($self->_is_version("1.4")) {
 		#we should ignore STDERR...
 		chomp($text = `$cmnd`);
     } else {
@@ -178,7 +157,7 @@ sub command_array {
     my $cmnd = $_[1];
     $self->_debug("command: ".$cmnd,1);
     my $text;
-    if ($self->_is_bad_version()) {
+    if ($self->_is_version("1.4")) {
 		#we should ignore STDERR...
 		chomp($text = `$cmnd`);
     } else {
@@ -204,8 +183,7 @@ sub question {
     my $args = $self->_pre($caller,@_);
 
     my $command = $self->_mk_cmnd(" --question",$args);
-    $command .= ' --text "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"' unless not $args->{'text'};
-
+    $command .= ' --text "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"' unless not $args->{'text'};
 
     my $rv = $self->command_state($command);
     $self->rv($rv||'null');
@@ -245,7 +223,7 @@ sub entry {
     my $args = $self->_pre($caller,@_);
 
     my $command = $self->_mk_cmnd(" --entry",$args);
-    $command .= ' --text "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"' unless not $args->{'text'};
+    $command .= ' --text "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"' unless not $args->{'text'};
     $command .= ' --hide-text' unless not $args->{'hide-text'};
     $command .= ' --entry-text "' . ($args->{'entry'}||$args->{'init'}) . '"'
      unless not $args->{'entry'} and not $args->{'init'};
@@ -285,7 +263,7 @@ sub info {
 
     my $command = $self->_mk_cmnd((($args->{'error'}) ? " --error" :
 								   ($args->{'warning'}) ? " --warning" : " --info"),$args);
-    $command .= ' --text "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"' unless not $args->{'text'};
+    $command .= ' --text "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"' unless not $args->{'text'};
 
     my $rv = $self->command_state($command);
     $self->rv($rv||'null');
@@ -364,11 +342,11 @@ sub list {
 
     my $command = $self->_mk_cmnd(" --list",$args);
     $command .= ($args->{'checklist'}) ? ' --checklist' : ($args->{'radiolist'}) ? ' --radiolist' : "";
-    $command .= ' --separator $\'\n\'';
+    $command .= ' --separator "\n"';
     #: not quite sure how to implement the editability...
     #    $command .= ' --editable' unless not $args->{'editable'};
     #: --text is not implemented for list widgets, yet...
-    #    $command .= ' --text "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"' unless not $args->{'text'};
+    #    $command .= ' --text "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"' unless not $args->{'text'};
 
     if ($args->{'list'} && ($args->{'checklist'} || $args->{'radiolist'})) {
 		if ($args->{'checklist'} || $args->{'radiolist'}) {
@@ -465,38 +443,6 @@ sub fselect {
     return($this_rv);
 }
 
-#:+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-#: directory select
-sub dselect {
-    my $self = shift();
-    my $caller = (caller(1))[3] || 'main';
-    $caller = ($caller =~ /^UI\:\:Dialog\:\:Backend\:\:/) ? ((caller(2))[3]||'main') : $caller;
-    if ($_[0] && $_[0] eq 'caller') { shift(); $caller = shift(); }
-    my $args = $self->_pre($caller,@_);
-
-    $args->{'path'} = (-d $args->{'path'}) ? $args->{'path'}."/" : $args->{'path'};
-    $args->{'path'} =~ s!/+!/!g;
-
-    my $command = $self->_mk_cmnd(" --file-selection --directory",$args);
-    $command .= ' --filename "' . ($args->{'path'}||abs_path()) . '"';
-
-    $self->_debug("fselect: ".$args->{'path'});
-    my ($rv,$file) = $self->command_string($command);
-    $self->rv($rv||'null');
-    $self->ra('null');
-    $self->rs('null');
-    my $this_rv;
-    if ($rv && $rv >= 1) {
-		$this_rv = 0;
-    } else {
-		$self->ra($file);
-		$self->rs($file);
-		$this_rv = $file;
-    }
-    $self->_post($args);
-    return($this_rv);
-}
-
 #:+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 #: calendar
 sub calendar {
@@ -507,7 +453,7 @@ sub calendar {
     my $args = $self->_pre($caller,@_);
 
     my $command = $self->_mk_cmnd(" --calendar",$args);
-    $command .= ' --text "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"' unless not $args->{'text'};
+    $command .= ' --text "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"' unless not $args->{'text'};
     $command .= ' --date-format "' . ($args->{'date-format'}||'%d/%m/%y') . '"';
     $command .= ' --day "' . $args->{'day'} . '"' unless not $args->{'day'};
     $command .= ' --month "' . $args->{'month'} . '"' unless not $args->{'month'};
@@ -521,8 +467,6 @@ sub calendar {
     if ($rv && $rv >= 1) {
 		$this_rv = 0;
     } else {
-		chomp($date);
-		# the end programmer can alter the date format
 		$self->ra(split(/\//,$date)) if $date =~ /^\d+\/\d+\/\d+$/;
 		$self->rs($date);
 		$this_rv = $date;
@@ -551,7 +495,7 @@ sub gauge_start {
     }
 
     my $command = $self->_mk_cmnd(" --progress",$args);
-    $command .= ' --text "' . (($args->{'literal'} ? $args->{'text'} : $self->_organize_text($args->{'text'},$args->{'width'}))||' ') . '"' unless not $args->{'text'};
+    $command .= ' --text "' . ($self->_organize_text($args->{'text'},$args->{'width'})||' ') . '"' unless not $args->{'text'};
     $command .= ' --percentage "' . ($args->{'percentage'}||'0') . '"';
     $command .= ' --pulsate' unless not $args->{'pulsate'};
 
