@@ -1,6 +1,6 @@
 package UI::Dialog::GNOME;
 ###############################################################################
-#  Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
+#  Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -18,13 +18,15 @@ package UI::Dialog::GNOME;
 ###############################################################################
 use 5.006;
 use strict;
+use warnings;
+use diagnostics;
 use Carp;
 use UI::Dialog;
 
 BEGIN {
     use vars qw( $VERSION @ISA );
     @ISA = qw( UI::Dialog );
-    $VERSION = '1.09';
+    $VERSION = '1.01';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -39,16 +41,7 @@ sub new {
     bless($self, $class);
 
     $self->{'debug'} = $cfg->{'debug'} || 0;
-
-	#: Dynamic path discovery...
-	my $CFG_PATH = $cfg->{'PATH'};
-	if ($CFG_PATH) {
-		if (ref($CFG_PATH) eq "ARRAY") { $self->{'PATHS'} = $CFG_PATH; }
-		elsif ($CFG_PATH =~ m!:!) { $self->{'PATHS'} = [ split(/:/,$CFG_PATH) ]; }
-		elsif (-d $CFG_PATH) { $self->{'PATHS'} = [ $CFG_PATH ]; }
-	} elsif ($ENV{'PATH'}) { $self->{'PATHS'} = [ split(/:/,$ENV{'PATH'}) ]; }
-	else { $self->{'PATHS'} = ''; }
-
+    $self->{'PATH'} = $cfg->{'PATH'} || '';
     $cfg->{'order'} ||= [ 'zenity', 'xdialog', 'gdialog' ];
 
     $self->_debug("ENV->UI_DIALOGS: ".($ENV{'UI_DIALOGS'}||'NULL'),2);
@@ -102,6 +95,4 @@ sub new {
     return($self);
 }
 
-sub editbox { return(shift()->{'_ui_dialog'}->editbox(@_)); }
-
 1;
